@@ -23,6 +23,9 @@ class ScanRunner(object):
     etl_retry = False
     timer_delay = 0.01
     max_scanner_running_threshold = None
+    ignore_limit = False
+    file_count = 0
+    line_count = 0
 
     @classmethod
     def get_scan_data(cls, req):
@@ -142,7 +145,7 @@ class ScanRunner(object):
             start_time = Utils.get_timestamp()
             container = client.containers.run(docker_image, command_line, volumes=volumes, detach=True, tty=False, stdout=True, stderr=True)
             # Terminate scans if running > xx minutes
-            if cls.max_scanner_running_threshold is not None:
+            if not cls.ignore_limit and cls.max_scanner_running_threshold is not None:
                 container.stop(timeout=cls.max_scanner_running_threshold*60)
             result = container.wait()
             
@@ -180,6 +183,8 @@ class ScanRunner(object):
             if scan_data['status'] == STATUS_ERROR_ETL_BLOCKED:
                 Utils.etl_waiting_countdown()
                 scan_data['status'] = STATUS_RUNNING
+
+            start_time = Utils.get_timestamp()
             print(('Launching scanner ' + scan_data['scanner']).ljust(50, ' '))
             output_file = cls.run_docker(scan_data)
             #output_file = cls.build_dir + scan_data['outputFile']
@@ -200,6 +205,7 @@ class ScanRunner(object):
             scan_data['endTime'] = Utils.get_formated_timestamp_timezone()
 
             cls.do_etl()
+            print(scan_data['scanner'] + ' scan completed. Time taken: ' + Utils.convert_seconds_to_time(Utils.get_timestamp() - start_time) + ', ' + format(cls.file_count, ',d') + ' files, ' + format(cls.line_count, ',d') + ' lines.')
         except DockerError as e:
             print(e.cli_message)
             # docker error found, set the current running data item to ERROR
@@ -249,6 +255,9 @@ class ScanRunner(object):
         cls.app_id = req['appid']
         cls.api_id = req['apiid']
         cls.build_dir = req['buildDir']
+        cls.ignore_limit = req['ignoreLimit']
+        cls.file_count = req['files']
+        cls.line_count = req['linesOfCode']
         Utils.create_skenoutput_folder(cls.build_dir + 'skenoutput')
 
         cls.get_scan_data(req)
