@@ -117,9 +117,6 @@ def check_language(command_line_params, yaml_config):
     if 'scanner' in command_line_params and command_line_params['scanner'] is not None:
         scanners = command_line_params['scanner']
 
-    if scanners.find('sast') < 0:
-        return True
-
     yaml_language = []
     if 'language' in yaml_config and yaml_config['language'] is not None:
         languages = yaml_config['language'].split(',')
@@ -137,10 +134,10 @@ def check_language(command_line_params, yaml_config):
     elif 'language' in yaml_config:
         del yaml_config['language']
 
-    return 'language' in yaml_config or 'language' in command_line_params
+    return 'language' in yaml_config or 'language' in command_line_params or (scanners != '' and scanners.find('sast') < 0)
 
 def version():
-    return '0.1.72'
+    return '0.1.73'
 
 def main():
     Utils.assert_docker_alive()
